package Bundle::Spiffy;
use strict;
use warnings;
use 5.006_001;
our $VERSION = '0.11';

__END__

=head1 NAME

Bundle::Spiffy - All the CPAN modules that are Spiffy

=head1 SYNOPSIS

    perl -MCPAN -e 'install Bundle::Spiffy'

=head1 DESCRIPTION

Spiffy is the 'Spiffy Perl Interface Framework For You'. This bundle
contains all the Spiffy CPAN modules.

=head1 CONTENTS

Spiffy

IO::All

Pointer

=head1 AUTHOR

Brian Ingerson <INGY@cpan.org>

=head1 COPYRIGHT

Copyright (c) 2003. Brian Ingerson. All rights reserved.

This bundle is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut
